@@ -1,4 +1,4 @@
-from __future__ import print_function
+from __future__ import print_function, absolute_import, division
 import os
 import yaml
 
@@ -10,6 +10,7 @@ USER_RC_PATH = os.path.abspath(os.path.expanduser('~/.ospreyrc'))
 
 
 def load_rcfile(verbose=True):
+
     def get_rc_path():
         path = os.getenv('OSPREYRC')
         if path == ' ':
@@ -25,7 +26,7 @@ def load_rcfile(verbose=True):
     if not path:
         return dict()
     if verbose:
-        print('Loading .ospreyrc from %s...' % path)
+        print('Loading .ospreyrc:       %s...' % path)
 
     with open(path) as f:
         return yaml.load(f) or dict()
