@@ -1,8 +1,10 @@
+from __future__ import print_function, absolute_import, division
 import os.path
 from os.path import samefile, abspath
 import tempfile
-from osprey.utils import dict_merge
-from osprey.utils import in_directory
+import datetime
+from osprey.utils import dict_merge, in_directory
+from osprey.utils import format_timedelta, current_pretty_time
 
 
 def test_dict_merge_1():
@@ -38,3 +40,11 @@ def test_in_directory_1():
         assert samefile(abspath(os.curdir), initialdir)
     finally:
         os.rmdir(tempdir)
+
+
+def test_format_timedelta():
+    print(format_timedelta(datetime.timedelta(seconds=413302.33)))
+
+
+def test_current_pretty_time():
+    print(current_pretty_time())
